===============
wafflehaus.iweb
===============

wafflehaus.iweb is a collection of waffles specific to iWeb.

See waffles READMEs for more details about each of them.

Using wafflehaus.iweb
---------------------

wafflehaus.iweb was created for iWeb specific needs.

Backward compatibility is **NOT** guaranteed. You are using it at your own risk.

If you think a feature could be useful to you, please let me know so it can be
proposed to the Wafflehaus project:

* `wafflehaus <https://github.com/roaet/wafflehaus>`_
